import os.path
import textwrap
from datetime import datetime
import logging

from .context import Context
from .utils import isoformat
from .xml import escape


logger = logging.getLogger(__name__)


class ReportingPostHandler:
    def __init__(self, service_url: str, reporting_dir: str):
        self.service_url = service_url
        self.reporting_dir = reporting_dir

    def __call__(self, config: dict, path: str, context: Context):
        inserted = datetime.now()
        timestamp = inserted.strftime("%Y%m%dT%H%M%S")
        filename = os.path.join(self.reporting_dir, 'item_%s_%s.xml' % (timestamp, context.identifier))
        logger.info(f"Generating report for path {path} at {filename}")
        with open(filename, 'w') as f:
            f.write(textwrap.dedent("""
                <?xml version="1.0" encoding="UTF-8"?>
                <DataAccessItemt
                    xsi:schemaLocation="http://www.telespazio.com/CSCDA/CDD/PDAS PDAS_interfaces%2020190924_1916.xsd"
                    xmlns="http://www.telespazio.com/CSCDA/CDD/PDAS"
                    xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance">
                  <identifier>{identifier}</identifier>
                  <BROWSE_AVAILABILITY_DATETIME>{availability_time}</BROWSE_AVAILABILITY_DATETIME>
                  <URL>
                      <Service>WCS</Service>
                      <URL>{wms_capabilities_url}</URL>
                  </URL>
                  <URL>
                      <Service>WMS</Service>
                      <URL>{wcs_capabilities_url}</URL>
                  </URL>
                </DataAccessItem>
            """.format(
                identifier=escape(context.identifier),
                availability_time=escape(isoformat(inserted)),
                wcs_capabilities_url=escape(
                    '%s/ows?service=wcs&request=GetCapabilities&cql=identifier="%s"'
                    % (self.service_url, context.identifier)
                ),
                wms_capabilities_url=escape(
                    '%s/ows?service=wms&request=GetCapabilities&cql=identifier="%s"'
                    % (self.service_url, context.identifier)
                ),
            )))
